﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO; 
using System.Threading.Tasks;

namespace ID3Test
{
    class ID3v1
    {
        //Konstanty
        private const int TAGPosition = -128;
        private const string TAGID = "TAG";

        public string Title = "";
        public string Artist = "";
        public string Album = "";
        public string Year = "";
        public string Comment = "";
        public byte Track = 0;
        public int Genre = 0;

        public static bool Exists(string Filename)
        {
            if (!System.IO.File.Exists(Filename))
                return false;

            FileStream fs = null;
            bool Ret = false;
            try
            {
                fs = File.OpenRead(Filename);
                long lngth = fs.Length - 128;
                fs.Seek(-128, SeekOrigin.End);
                string Head = ReadValue(fs, 3);
                Ret = (Head == TAGID);
            }
            catch
            {
                Ret = false;
            }
            finally
            {
                if (fs != null)
                {
                    fs.Close();
                }
            }
            return Ret;
        }

        public static ID3v1 ReadTag(string Filename)
        {
            FileStream fs = null;
            ID3v1 Ret = null;
            try
            {
                if (System.IO.File.Exists(Filename))
                {
                    fs = File.OpenRead(Filename);
                    long lngth = fs.Length - 128;
                    fs.Seek(-128, SeekOrigin.End);

                    string Head = ReadValue(fs, 3);
                    if (Head == TAGID)
                    {
                        Ret = new ID3v1();
                        Ret.Title = ReadValue(fs, 30);
                        Ret.Artist = ReadValue(fs, 30);
                        Ret.Album = ReadValue(fs, 30);
                        Ret.Year = ReadValue(fs, 4);

                        string Comment = ReadValue(fs, 30);
                        if (Comment.Length == 30
                            && Comment[Comment.Length - 2] == '\0' && Comment[Comment.Length - 1] != '\0')
                        {
                            Ret.Comment = Comment.Substring(0, 28).Trim();
                            Ret.Track = Convert.ToByte(Comment[Comment.Length - 1]);
                        }
                        else
                        {
                            Ret.Comment = Comment;
                        }

                        Ret.Genre = fs.ReadByte();
                    }
                }
            }
            catch
            {
                Ret = null;
            }
            finally
            {
                if (fs != null)
                {
                    fs.Close();
                }
            }

            return Ret;
        }

        private static string ReadValue(FileStream fs, int ValueLength)
        {
            //Kontrola, ci sa nepokusame nacitat viac ako je k dispozicii
            if (fs.Position + ValueLength > fs.Length)
            {
                ValueLength = (int)(fs.Length - fs.Position);
            }

            if (ValueLength <= 0)
                return "";

            byte[] Buffer = new byte[ValueLength];

            int Read = fs.Read(Buffer, 0, (int)ValueLength);

            return TrimZeros(System.Text.Encoding.ASCII.GetString(Buffer, 0, Read));
        }

        private static string TrimZeros(string Value)
        {
            return Value.Trim(new char[] { '\0' });
        }
    }
}