﻿using Id3; //<-----
using Id3.Frames;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ID3Test
{
    class Program
    {
        static void Main(string[] args)
        {
            string Filename = @"[cesta_k_suboru]\test.mp3";

            Console.WriteLine("ID3v1");
            ReadID3v1(Filename);
            Console.WriteLine();
            Console.WriteLine("ID3v2");
            ReadID3v2(Filename);
            Console.WriteLine();

            Console.ReadLine();
        }

        private static void ReadID3v1(string Filename)
        {
            if (ID3v1.Exists(Filename))
            {
                ID3v1 Tag = ID3v1.ReadTag(Filename);
                if (Tag != null)
                {
                    Console.WriteLine("Nazov skladby: " + Tag.Title);
                    Console.WriteLine("Interpret: " + Tag.Artist);
                    Console.WriteLine("Album: " + Tag.Album);
                    Console.WriteLine("Rok: " + Tag.Year);
                    if (!String.IsNullOrEmpty(Tag.Comment))
                    {
                        Console.WriteLine("Komentar: " + Tag.Comment);
                    }
                    Console.WriteLine("Zaner: " + Convert.ToString(Tag.Genre));
                    if (Tag.Track != 0)
                    {
                        Console.WriteLine("Cislo skladby: " + Convert.ToString(Tag.Track));
                    }
                }
                else
                {
                    Console.WriteLine("Pri nacitani ID3v1 tagu doslo k chybe.");
                }
            }
            else
            {
                Console.WriteLine("Subor neobsahuje ID3v1 tag");
            }
        }

        private static void ReadID3v2(string Filename)
        {
            Mp3 file = new Mp3(Filename, Mp3Permissions.Read);
            if (file.HasTagOfVersion(Id3Version.V23))
            {
                Id3Tag Tag = file.GetTag(Id3Version.V23);

                if (Tag.Title != null)
                    Console.WriteLine("Nazov skladby: " + Tag.Title.Value);

                if (Tag.Band != null)
                    Console.WriteLine("Interpret: " + Tag.Band.Value);

                if (Tag.Album != null)
                    Console.WriteLine("Album: " + Tag.Album.Value);

                if (Tag.Year != null)
                    Console.WriteLine("Rok: " + Tag.Year.Value);

                string Comments = "";
                if (Tag.Comments != null)
                {
                    foreach (CommentFrame Frame in Tag.Comments)
                    {
                        if (Comments != "")
                            Comments += ", ";

                        Comments += Frame.Comment;
                    }
                }

                if (Comments != "")
                    Console.WriteLine("Komentar: " + Comments);

                if (Tag.Genre != null)
                    Console.WriteLine("Zaner: " + Convert.ToString(Tag.Genre.Value));

                if (Tag.Track != null)
                    Console.WriteLine("Cislo skladby: " + Tag.Track.Value);
            }
            else
            {
                Console.WriteLine("Subor neobsahuje ID3v2 tag");
            }
        }
    }
}
